==> jc-1.4.0.tar.gz: javax/naming/NamingSecurityException.h <==
// public abstract class javax.naming.NamingSecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 65ccc046b885c942 javax_naming_NamingSecurityException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_NamingSecurityException_H_
#define _JC_javax_naming_NamingSecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_NamingSecurityException$sub_refs	_jc_javax_naming_NamingSecurityException$sub_refs;
typedef struct _jc_javax_naming_NamingSecurityException$sub_nonrefs	_jc_javax_naming_NamingSecurityException$sub_nonrefs;
typedef struct _jc_javax_naming_NamingSecurityException$refs	_jc_javax_naming_NamingSecurityException$refs;
typedef struct _jc_javax_naming_NamingSecurityException$nonrefs	_jc_javax_naming_NamingSecurityException$nonrefs;
typedef struct _jc_javax_naming_NamingSecurityException$object	_jc_javax_naming_NamingSecurityException$object;

typedef struct _jc_javax_naming_NamingSecurityException$fields_struct	_jc_javax_naming_NamingSecurityException$fields_struct;
typedef const struct _jc_javax_naming_NamingSecurityException$vmethods	_jc_javax_naming_NamingSecurityException$vmethods;
typedef const struct _jc_javax_naming_NamingSecurityException$vtable	_jc_javax_naming_NamingSecurityException$vtable;
typedef const struct _jc_javax_naming_NamingSecurityException$vtype	_jc_javax_naming_NamingSecurityException$vtype;

// Class fields structure
struct _jc_javax_naming_NamingSecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_NamingSecurityException$fields_struct _jc_javax_naming_NamingSecurityException$class_fields;

// Constructors
extern void _jc_javax_naming_NamingSecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_NamingSecurityException$object *);
extern void _jc_javax_naming_NamingSecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_NamingSecurityException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_naming_NamingSecurityException$vmethods {
};

// Vtable
struct _jc_javax_naming_NamingSecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_NamingSecurityException$vmethods	javax_naming_NamingSecurityException;
};

// Vtype
struct _jc_javax_naming_NamingSecurityException$vtype {
	_jc_type			type;
	_jc_javax_naming_NamingSecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_NamingSecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_NamingSecurityException$refs {
    _jc_javax_naming_NamingSecurityException$sub_refs	javax_naming_NamingSecurityException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_NamingSecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_NamingSecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_NamingSecurityException$sub_nonrefs	javax_naming_NamingSecurityException;
};

// Object instance structure
struct _jc_javax_naming_NamingSecurityException$object {
	_jc_javax_naming_NamingSecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_NamingSecurityException$vtype	*vtype;
	_jc_javax_naming_NamingSecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_NamingSecurityException$vtype _jc_javax_naming_NamingSecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_NamingSecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_NamingSecurityException$class_object;

#endif	/* _JC_javax_naming_NamingSecurityException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/NamingSecurityException.h <==
// public abstract class javax.naming.NamingSecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 65ccc046b885c942 javax_naming_NamingSecurityException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_NamingSecurityException_H_
#define _JC_javax_naming_NamingSecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_NamingSecurityException$sub_refs	_jc_javax_naming_NamingSecurityException$sub_refs;
typedef struct _jc_javax_naming_NamingSecurityException$sub_nonrefs	_jc_javax_naming_NamingSecurityException$sub_nonrefs;
typedef struct _jc_javax_naming_NamingSecurityException$refs	_jc_javax_naming_NamingSecurityException$refs;
typedef struct _jc_javax_naming_NamingSecurityException$nonrefs	_jc_javax_naming_NamingSecurityException$nonrefs;
typedef struct _jc_javax_naming_NamingSecurityException$object	_jc_javax_naming_NamingSecurityException$object;

typedef struct _jc_javax_naming_NamingSecurityException$fields_struct	_jc_javax_naming_NamingSecurityException$fields_struct;
typedef const struct _jc_javax_naming_NamingSecurityException$vmethods	_jc_javax_naming_NamingSecurityException$vmethods;
typedef const struct _jc_javax_naming_NamingSecurityException$vtable	_jc_javax_naming_NamingSecurityException$vtable;
typedef const struct _jc_javax_naming_NamingSecurityException$vtype	_jc_javax_naming_NamingSecurityException$vtype;

// Class fields structure
struct _jc_javax_naming_NamingSecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_NamingSecurityException$fields_struct _jc_javax_naming_NamingSecurityException$class_fields;

// Constructors
extern void _jc_javax_naming_NamingSecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_NamingSecurityException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_NamingSecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_NamingSecurityException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_NamingSecurityException$vmethods {
};

// Vtable
struct _jc_javax_naming_NamingSecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_NamingSecurityException$vmethods	javax_naming_NamingSecurityException;
};

// Vtype
struct _jc_javax_naming_NamingSecurityException$vtype {
	_jc_type			type;
	_jc_javax_naming_NamingSecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_NamingSecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_NamingSecurityException$refs {
    _jc_javax_naming_NamingSecurityException$sub_refs	javax_naming_NamingSecurityException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_NamingSecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_NamingSecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_NamingSecurityException$sub_nonrefs	javax_naming_NamingSecurityException;
};

// Object instance structure
struct _jc_javax_naming_NamingSecurityException$object {
	_jc_javax_naming_NamingSecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_NamingSecurityException$vtype	*vtype;
	_jc_javax_naming_NamingSecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_NamingSecurityException$vtype _jc_javax_naming_NamingSecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_NamingSecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_NamingSecurityException$class_object;

#endif	/* _JC_javax_naming_NamingSecurityException_H_ */
